@@ -7,10 +7,11 @@
 import configparser
 import os
 import subprocess
+from typing import Set
 
 from flake8 import exceptions as exc
 
-__all__ = ('hook', 'install')
+__all__ = ("hook", "install")
 
 
 def hook(ui, repo, **kwargs):
@@ -24,13 +25,14 @@ def hook(ui, repo, **kwargs):
     avoid using it all the same.
     """
     from flake8.main import application
+
     hgrc = find_hgrc(create_if_missing=False)
     if hgrc is None:
-        print('Cannot locate your root mercurial repository.')
+        print("Cannot locate your root mercurial repository.")
         raise SystemExit(True)
 
     hgconfig = configparser_for(hgrc)
-    strict = hgconfig.get('flake8', 'strict', fallback=True)
+    strict = hgconfig.get("flake8", "strict", fallback=True)
 
     filenames = list(get_filenames_from(repo, kwargs))
 
@@ -68,42 +70,40 @@ def install():
 
     hgconfig = configparser_for(hgrc)
 
-    if not hgconfig.has_section('hooks'):
-        hgconfig.add_section('hooks')
+    if not hgconfig.has_section("hooks"):
+        hgconfig.add_section("hooks")
 
-    if hgconfig.has_option('hooks', 'commit'):
+    if hgconfig.has_option("hooks", "commit"):
         raise exc.MercurialCommitHookAlreadyExists(
-            path=hgrc,
-            value=hgconfig.get('hooks', 'commit'),
+            path=hgrc, value=hgconfig.get("hooks", "commit")
         )
 
-    if hgconfig.has_option('hooks', 'qrefresh'):
+    if hgconfig.has_option("hooks", "qrefresh"):
         raise exc.MercurialQRefreshHookAlreadyExists(
-            path=hgrc,
-            value=hgconfig.get('hooks', 'qrefresh'),
+            path=hgrc, value=hgconfig.get("hooks", "qrefresh")
         )
 
-    hgconfig.set('hooks', 'commit', 'python:flake8.main.mercurial.hook')
-    hgconfig.set('hooks', 'qrefresh', 'python:flake8.main.mercurial.hook')
+    hgconfig.set("hooks", "commit", "python:flake8.main.mercurial.hook")
+    hgconfig.set("hooks", "qrefresh", "python:flake8.main.mercurial.hook")
 
-    if not hgconfig.has_section('flake8'):
-        hgconfig.add_section('flake8')
+    if not hgconfig.has_section("flake8"):
+        hgconfig.add_section("flake8")
 
-    if not hgconfig.has_option('flake8', 'strict'):
-        hgconfig.set('flake8', 'strict', False)
+    if not hgconfig.has_option("flake8", "strict"):
+        hgconfig.set("flake8", "strict", False)
 
-    with open(hgrc, 'w') as fd:
+    with open(hgrc, "w") as fd:
         hgconfig.write(fd)
 
-    print('mercurial hooks installed, for configuration options see')
-    print('http://flake8.pycqa.org/en/latest/user/using-hooks.html')
+    print("mercurial hooks installed, for configuration options see")
+    print("http://flake8.pycqa.org/en/latest/user/using-hooks.html")
 
     return True
 
 
 def get_filenames_from(repository, kwargs):
-    seen_filenames = set()
-    node = kwargs['node']
+    seen_filenames = set()  # type: Set[str]
+    node = kwargs["node"]
     for revision in range(repository[node], len(repository)):
         for filename in repository[revision].files():
             full_filename = os.path.join(repository.root, filename)
@@ -113,30 +113,26 @@ def get_filenames_from(repository, kwargs):
                 continue
 
             seen_filenames.add(full_filename)
-            if full_filename.endswith('.py'):
+            if full_filename.endswith(".py"):
                 yield full_filename
 
 
 def find_hgrc(create_if_missing=False):
     root = subprocess.Popen(
-        ['hg', 'root'],
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
+        ["hg", "root"], stdout=subprocess.PIPE, stderr=subprocess.PIPE
     )
 
     (hg_directory, _) = root.communicate()
-    if callable(getattr(hg_directory, 'decode', None)):
-        hg_directory = hg_directory.decode('utf-8')
+    if callable(getattr(hg_directory, "decode", None)):
+        hg_directory = hg_directory.decode("utf-8")
 
     if not os.path.isdir(hg_directory):
         return None
 
-    hgrc = os.path.abspath(
-        os.path.join(hg_directory, '.hg', 'hgrc')
-    )
+    hgrc = os.path.abspath(os.path.join(hg_directory, ".hg", "hgrc"))
     if not os.path.exists(hgrc):
         if create_if_missing:
-            open(hgrc, 'w').close()
+            open(hgrc, "w").close()
         else:
             return None
 
