@@ -44,7 +44,9 @@ def test_format_needs_to_be_implemented():
     """Ensure BaseFormatter#format raises a NotImplementedError."""
     formatter = base.BaseFormatter(options())
     with pytest.raises(NotImplementedError):
-        formatter.format('foo')
+        formatter.format(
+            style_guide.Violation('A000', 'file.py', 1, 1, 'error text', None)
+        )
 
 
 def test_show_source_returns_nothing_when_not_showing_source():
@@ -52,7 +54,7 @@ def test_show_source_returns_nothing_when_not_showing_source():
     formatter = base.BaseFormatter(options(show_source=False))
     assert formatter.show_source(
         style_guide.Violation('A000', 'file.py', 1, 1, 'error text', 'line')
-    ) is ''
+    ) == ''
 
 
 def test_show_source_returns_nothing_when_there_is_source():
@@ -60,7 +62,7 @@ def test_show_source_returns_nothing_when_there_is_source():
     formatter = base.BaseFormatter(options(show_source=True))
     assert formatter.show_source(
         style_guide.Violation('A000', 'file.py', 1, 1, 'error text', None)
-    ) is ''
+    ) == ''
 
 
 @pytest.mark.parametrize('line, column', [
@@ -73,6 +75,7 @@ def test_show_source_updates_physical_line_appropriately(line, column):
     formatter = base.BaseFormatter(options(show_source=True))
     error = style_guide.Violation('A000', 'file.py', 1, column, 'error', line)
     output = formatter.show_source(error)
+    assert output
     _, pointer = output.rsplit('\n', 1)
     assert pointer.count(' ') == (column - 1)
 
