@@ -1,6 +1,8 @@
 """Unit tests for the FileChecker class."""
 import mock
+import pytest
 
+import flake8
 from flake8 import checker
 
 
@@ -43,3 +45,20 @@ def test_nonexistent_file():
     assert len(c.results) == 1
     error = c.results[0]
     assert error[0] == "E902"
+
+
+def test_raises_exception_on_failed_plugin(tmp_path, default_options):
+    """Checks that a failing plugin results in PluginExecutionFailed."""
+    foobar = tmp_path / 'foobar.py'
+    foobar.write_text(u"I exist!")  # Create temp file
+    plugin = {
+        "name": "failure",
+        "plugin_name": "failure",  # Both are necessary
+        "parameters": dict(),
+        "plugin": mock.MagicMock(side_effect=ValueError),
+    }
+    """Verify a failing plugin results in an plugin error"""
+    fchecker = checker.FileChecker(
+        str(foobar), checks=[], options=default_options)
+    with pytest.raises(flake8.exceptions.PluginExecutionFailed):
+        fchecker.run_check(plugin)
