@@ -1,17 +1,10 @@
 """Tests for flake8.plugins.manager.PluginTypeManager."""
-import sys
-
 import mock
 import pytest
 
 from flake8 import exceptions
 from flake8.plugins import manager
 
-if sys.version_info >= (3, 3):
-    import collections.abc as collections_abc
-else:
-    import collections as collections_abc
-
 TEST_NAMESPACE = "testing.plugin-type-manager"
 
 
@@ -91,7 +84,7 @@ def test_generate_call_function():
         'method_name', optmanager,
     )
 
-    assert isinstance(func, collections_abc.Callable)
+    assert callable(func)
     assert func(plugin) is optmanager
 
 
@@ -168,15 +161,14 @@ def test_provide_options(PluginManager):  # noqa: N803
     PluginManager.return_value = create_mapping_manager_mock(plugins)
     optmanager = object()
     options = object()
-    extra_args = []
 
     type_mgr = FakeTestType()
-    type_mgr.provide_options(optmanager, options, extra_args)
+    type_mgr.provide_options(optmanager, options, [])
 
     for plugin in plugins:
         plugin.provide_options.assert_called_with(optmanager,
                                                   options,
-                                                  extra_args)
+                                                  [])
 
 
 @mock.patch('flake8.plugins.manager.PluginManager')
@@ -203,31 +195,3 @@ def test_proxies_getitem_to_managers_plugins_dict(PluginManager):  # noqa: N803
     for i in range(8):
         key = 'T10%i' % i
         assert type_mgr[key] is plugins[key]
-
-
-class FakePluginTypeManager(manager.NotifierBuilderMixin):
-    """Provide an easy way to test the NotifierBuilderMixin."""
-
-    def __init__(self, manager):
-        """Initialize with our fake manager."""
-        self.names = sorted(manager)
-        self.manager = manager
-
-
-@pytest.fixture
-def notifier_builder():
-    """Create a fake plugin type manager."""
-    return FakePluginTypeManager(manager={
-        'T100': object(),
-        'T101': object(),
-        'T110': object(),
-    })
-
-
-def test_build_notifier(notifier_builder):
-    """Verify we properly build a Notifier object."""
-    notifier = notifier_builder.build_notifier()
-    for name in ('T100', 'T101', 'T110'):
-        assert list(notifier.listeners_for(name)) == [
-            notifier_builder.manager[name]
-        ]
