@@ -4,6 +4,7 @@ import os
 import mock
 import pytest
 
+from flake8 import exceptions
 from flake8 import utils
 from flake8.plugins import manager as plugin_manager
 
@@ -32,6 +33,94 @@ def test_parse_comma_separated_list(value, expected):
     assert utils.parse_comma_separated_list(value) == expected
 
 
+@pytest.mark.parametrize(
+    ('value', 'expected'),
+    (
+        # empty option configures nothing
+        ('', []), ('   ', []), ('\n\n\n', []),
+        # basic case
+        (
+            'f.py:E123',
+            [('f.py', ['E123'])],
+        ),
+        # multiple filenames, multiple codes
+        (
+            'f.py,g.py:E,F',
+            [('f.py', ['E', 'F']), ('g.py', ['E', 'F'])],
+        ),
+        # demonstrate that whitespace is not important around tokens
+        (
+            '   f.py  , g.py  : E  , F  ',
+            [('f.py', ['E', 'F']), ('g.py', ['E', 'F'])],
+        ),
+        # whitespace can separate groups of configuration
+        (
+            'f.py:E g.py:F',
+            [('f.py', ['E']), ('g.py', ['F'])],
+        ),
+        # newlines can separate groups of configuration
+        (
+            'f.py: E\ng.py: F\n',
+            [('f.py', ['E']), ('g.py', ['F'])],
+        ),
+        # whitespace can be used in place of commas
+        (
+            'f.py g.py: E F',
+            [('f.py', ['E', 'F']), ('g.py', ['E', 'F'])],
+        ),
+        # go ahead, indent your codes
+        (
+            'f.py:\n    E,F\ng.py:\n    G,H',
+            [('f.py', ['E', 'F']), ('g.py', ['G', 'H'])],
+        ),
+        # capitalized filenames are ok too
+        (
+            'F.py,G.py: F,G',
+            [('F.py', ['F', 'G']), ('G.py', ['F', 'G'])],
+        ),
+        #  it's easier to allow zero filenames or zero codes than forbid it
+        (':E', []), ('f.py:', []),
+        (':E f.py:F', [('f.py', ['F'])]),
+        ('f.py: g.py:F', [('g.py', ['F'])]),
+        ('f.py:E:', []),
+        ('f.py:E.py:', []),
+        ('f.py:Eg.py:F', [('Eg.py', ['F'])]),
+        # sequences are also valid (?)
+        (
+            ['f.py:E,F', 'g.py:G,H'],
+            [('f.py', ['E', 'F']), ('g.py', ['G', 'H'])],
+        ),
+        # six-digits codes are allowed
+        (
+            'f.py: ABC123',
+            [('f.py', ['ABC123'])],
+        )
+    ),
+)
+def test_parse_files_to_codes_mapping(value, expected):
+    """Test parsing of valid files-to-codes mappings."""
+    assert utils.parse_files_to_codes_mapping(value) == expected
+
+
+@pytest.mark.parametrize(
+    'value',
+    (
+        # code while looking for filenames
+        'E123', 'f.py,E123', 'f.py E123',
+        # eof while looking for filenames
+        'f.py', 'f.py:E,g.py'
+        # colon while looking for codes
+        'f.py::',
+        # no separator between
+        'f.py:E1F1',
+    ),
+)
+def test_invalid_file_list(value):
+    """Test parsing of invalid files-to-codes mappings."""
+    with pytest.raises(exceptions.ExecutionError):
+        utils.parse_files_to_codes_mapping(value)
+
+
 @pytest.mark.parametrize("value,expected", [
     ("flake8", "flake8"),
     ("../flake8", os.path.abspath("../flake8")),
@@ -74,12 +163,6 @@ def test_fnmatch(filename, patterns, expected):
     assert utils.fnmatch(filename, patterns) is expected
 
 
-def test_fnmatch_returns_the_default_with_empty_default():
-    """The default parameter should be returned when no patterns are given."""
-    sentinel = object()
-    assert utils.fnmatch('file.py', [], default=sentinel) is sentinel
-
-
 def test_filenames_from_a_directory():
     """Verify that filenames_from walks a directory."""
     filenames = list(utils.filenames_from('src/flake8/'))
